==> cmpparis-1.8.3.tar.gz: cmpparis-1.8.3/cmpparis/error_handling.py <==
import logging
import sys
import traceback
from airflow.exceptions import AirflowException
from contextlib import contextmanager
from ses_utils import send_email_to_support

###
# Returns placeholdered string used in the subject of the email sent
#
# Ex: [Products - Airflow dag quable_to_colombus] - read_configuration
#
# return string
###
def get_error_subject():
    return '{} - {}'

def format_exception_info(exc_info, format = None):
    exc_type, exc_value, exc_traceback = exc_info

    # Get the full traceback details
    tb_details = traceback.extract_tb(exc_traceback)

    # Get the last frame (where the error occurred)
    last_frame = tb_details[-1]
    filename, line_number, func_name, text = last_frame

    match format:
        case 'html':
            formatted_error = f"""
                <p><b>Error Type:</b> {exc_type.__name__}</p>
                <p><b>Message:</b> {str(exc_value)}</p>
                <p><b>Location:</b>
                    <ul>
                        <li><b>File:</b> {filename}</li>
                        <li><b>Line:</b> {line_number}</li>
                        <li><b>Function:</b> {func_name}</li>
                        <li><b>Code:</b> {text}</li>
                    </ul>
                </p>
            """
        case _:
            formatted_error = f"""
                {'='*50}
                Error Type: {exc_type.__name__}
                Message: {str(exc_value)}
                Location:
                File: {filename}
                Line: {line_number}
                Function: {func_name}
                Code: {text}
                {'='*50}
            """

    return formatted_error

@contextmanager
def error_handling(system_name, function_name):
    try:
        yield
    except Exception as e:
        error_subject = get_error_subject().format(system_name, function_name)
        formatted_exception = format_exception_info(sys.exc_info())
        formatted_exception_html = format_exception_info(sys.exc_info(), 'html')
        error_message = f"Error while executing {function_name} : \n\n {formatted_exception}"
        error_message_html = f"An error occurred while executing {function_name} : <br><br> {formatted_exception_html}"
        logging.error(error_message)
        send_email_to_support(error_subject, error_message_html)
        
        if 'airflow' in system_name:
            raise AirflowException(error_message)
        else:
            raise e

==> cmpparis-1.9.4.tar.gz: cmpparis-1.9.4/cmpparis/error_handling.py <==
import logging
import sys
import traceback
from airflow.exceptions import AirflowException
from contextlib import contextmanager
from .ses_utils import send_email_to_support

###
# Returns placeholdered string used in the subject of the email sent
#
# Ex: [Products - Airflow dag quable_to_colombus] - read_configuration
#
# return string
###
def get_error_subject():
    return '{} - {}'

def format_exception_info(exc_info, format = None):
    exc_type, exc_value, exc_traceback = exc_info

    # Get the full traceback details
    tb_details = traceback.extract_tb(exc_traceback)

    # Get the last frame (where the error occurred)
    last_frame = tb_details[-1]
    filename, line_number, func_name, text = last_frame

    match format:
        case 'html':
            formatted_error = f"""
                <p><b>Error Type:</b> {exc_type.__name__}</p>
                <p><b>Message:</b> {str(exc_value)}</p>
                <p><b>Location:</b>
                    <ul>
                        <li><b>File:</b> {filename}</li>
                        <li><b>Line:</b> {line_number}</li>
                        <li><b>Function:</b> {func_name}</li>
                        <li><b>Code:</b> {text}</li>
                    </ul>
                </p>
            """
        case _:
            formatted_error = f"""
                {'='*50}
                Error Type: {exc_type.__name__}
                Message: {str(exc_value)}
                Location:
                File: {filename}
                Line: {line_number}
                Function: {func_name}
                Code: {text}
                {'='*50}
            """

    return formatted_error

@contextmanager
def error_handling(system_name, function_name):
    try:
        yield
    except Exception as e:
        error_subject = get_error_subject().format(system_name, function_name)
        formatted_exception = format_exception_info(sys.exc_info())
        formatted_exception_html = format_exception_info(sys.exc_info(), 'html')
        error_message = f"Error while executing {function_name} : \n\n {formatted_exception}"
        error_message_html = f"An error occurred while executing {function_name} : <br><br> {formatted_exception_html}"
        logging.error(error_message)
        send_email_to_support(error_subject, error_message_html)
        
        if 'airflow' in system_name:
            raise AirflowException(error_message)
        else:
            raise e
